# Changelog

## v0.3.0rc0

([full changelog](https://github.com/jupyterlab/retrolab/compare/0.3.0b0...96671df35822f09721fd2e5df7118ce4fa2225ea))

### Enhancements made

- `jupyter retro --version` returns the version [#177](https://github.com/jupyterlab/retrolab/pull/177) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Update to jupyter-packaging 0.10 [#179](https://github.com/jupyterlab/retrolab/pull/179) ([@jtpio](https://github.com/jtpio))
- Reuse mobile view CSS from upstream JupyterLab [#178](https://github.com/jupyterlab/retrolab/pull/178) ([@jtpio](https://github.com/jtpio))
- Update to JupyterLab 3.1.0rc1 [#176](https://github.com/jupyterlab/retrolab/pull/176) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-07-06&to=2021-07-14&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-07-06..2021-07-14&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-07-06..2021-07-14&type=Issues)

## v0.3.0b0

([full changelog](https://github.com/jupyterlab/retrolab/compare/0.3.0a2...574da61aa7c8cc4aa6840b0e548860f7ceeb11dc))

### Maintenance and upkeep improvements

- Update to JupyterLab 3.1.0-beta.0 packages [#167](https://github.com/jupyterlab/retrolab/pull/167) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- Check the application status before closing the tab [#166](https://github.com/jupyterlab/retrolab/pull/166) ([@jtpio](https://github.com/jtpio))
- Backport PR #159 on branch 0.2.x (Mimic classic notebook behavior for /tree/<path>) [#161](https://github.com/jupyterlab/retrolab/pull/161) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Mimic classic notebook behavior for /tree/<path> [#159](https://github.com/jupyterlab/retrolab/pull/159) ([@yuvipanda](https://github.com/yuvipanda))
- [0.2.x] Backport #148 (Enable hub-extension) [#151](https://github.com/jupyterlab/retrolab/pull/151) ([@jtpio](https://github.com/jtpio))
- Backport PR #138 on branch 0.2.x (Easier to access RetroLab tree) [#150](https://github.com/jupyterlab/retrolab/pull/150) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Enable hub-extension [#148](https://github.com/jupyterlab/retrolab/pull/148) ([@jabbera](https://github.com/jabbera))
- Backport PR #144 on branch 0.2.x (Trigger CI on all branches for `push` events) [#145](https://github.com/jupyterlab/retrolab/pull/145) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Trigger CI on all branches for `push` events [#144](https://github.com/jupyterlab/retrolab/pull/144) ([@jtpio](https://github.com/jtpio))
- Backport PR #137 on branch 0.2.x (Follow-up to the move to the `jupyterlab` organization) [#142](https://github.com/jupyterlab/retrolab/pull/142) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Backport PR #140 on branch 0.2.x (Fix release workflow) [#141](https://github.com/jupyterlab/retrolab/pull/141) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Fix release workflow [#140](https://github.com/jupyterlab/retrolab/pull/140) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-05-28&to=2021-07-06&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Afcollonval+updated%3A2021-05-28..2021-07-06&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-05-28..2021-07-06&type=Issues) | [@jabbera](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajabbera+updated%3A2021-05-28..2021-07-06&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-05-28..2021-07-06&type=Issues) | [@meeseeksmachine](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ameeseeksmachine+updated%3A2021-05-28..2021-07-06&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2021-05-28..2021-07-06&type=Issues) | [@yuvipanda](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ayuvipanda+updated%3A2021-05-28..2021-07-06&type=Issues)
